@@ -35,6 +35,7 @@
 #include "ms-chart.h"
 #include "ms-escher.h"
 #include "ms-excel-util.h"
+#include "ms-formula-write.h"
 
 #include <expr.h>
 #include <parse-util.h>
@@ -452,7 +453,8 @@ ms_read_TXO (BiffQuery *q, MSContainer *c, PangoAttrList **markup)
 			*markup = ms_container_read_markup (c, q->data, q->length,
 							    text);
 		} else {
-			g_warning ("Unusual, TXO text with no formatting has 0x%x @ 0x%x", op, q->streamPos);
+			g_warning ("Unusual, TXO text with no formatting has 0x%x @ 0x%lx",
+				   op, (long)q->streamPos);
 		}
 	} else {
 		g_warning ("TXO len of %d but no continue", text_len);
@@ -990,6 +992,8 @@ ms_obj_read_biff8_obj (BiffQuery *q, MSContainer *c, MSObj *obj)
 			break;
 
 		case GR_MACRO :
+			ms_obj_read_expr (obj, MS_OBJ_ATTR_MACRO_EXPR, c,
+				data+4, data + 4 + len);
 			ms_obj_dump (data, len, data_len_left, "MacroObject");
 			break;
 
@@ -1382,3 +1386,98 @@ ms_objv8_write_note (BiffPut *bp)
 	memcpy (buf, data, sizeof data);
 	ms_biff_put_var_write (bp, buf, sizeof data);
 }
+
+void
+ms_objv8_write_checkbox_data (BiffPut *bp, gboolean active)
+{
+	char cboxdata[12];
+
+	GSF_LE_SET_GUINT16 (cboxdata, GR_CHECKBOX_DATA);
+	GSF_LE_SET_GUINT16 (cboxdata + 2, sizeof (cboxdata) - 4);
+	GSF_LE_SET_GUINT16 (cboxdata + 4, active);
+	GSF_LE_SET_GUINT16 (cboxdata + 6, 0); /* accel */
+	GSF_LE_SET_GUINT16 (cboxdata + 8, 0); /* reserved */
+	GSF_LE_SET_GUINT16 (cboxdata + 10, 2);  /* 3d display.  */
+	ms_biff_put_var_write (bp, cboxdata, sizeof cboxdata);
+}
+
+void
+ms_objv8_write_checkbox_link (BiffPut *bp)
+{
+	char data[16];
+
+	GSF_LE_SET_GUINT16 (data, GR_CHECKBOX_LINK);
+	GSF_LE_SET_GUINT16 (data + 2, sizeof (data) - 4);
+	GSF_LE_SET_GUINT32 (data + 4, 1); /* ? */
+	GSF_LE_SET_GUINT32 (data + 8, 0); /* ? */
+	GSF_LE_SET_GUINT32 (data + 12, 0); /* ? */
+	ms_biff_put_var_write (bp, data, sizeof data);
+}
+
+void
+ms_objv8_write_checkbox_fmla (BiffPut *bp,
+			      ExcelWriteSheet *esheet,
+			      GnmExprTop const *texpr)
+{
+	char hfmla[10];
+	unsigned pos, end_pos;
+	guint16 fmla_len;
+
+	pos = bp->curpos;
+	GSF_LE_SET_GUINT16 (hfmla, GR_CHECKBOX_FORMULA);
+	GSF_LE_SET_GUINT16 (hfmla + 2, 0);  /* record len */
+	GSF_LE_SET_GUINT16 (hfmla + 4, 0);  /* formula len */
+	GSF_LE_SET_GUINT32 (hfmla + 6, 0);  /* calcid? */
+	ms_biff_put_var_write (bp, hfmla, sizeof hfmla);
+	fmla_len = excel_write_formula (esheet->ewb,
+					texpr,
+					esheet->gnum_sheet, 0, 0,
+					/* eh?  */
+					EXCEL_CALLED_FROM_VALIDATION);
+	end_pos = bp->curpos;
+	ms_biff_put_var_seekto (bp, pos);
+	GSF_LE_SET_GUINT16 (hfmla + 2, fmla_len + 6);
+	GSF_LE_SET_GUINT16 (hfmla + 4, fmla_len);
+	ms_biff_put_var_write (bp, hfmla, sizeof hfmla);
+	ms_biff_put_var_seekto (bp, end_pos);
+}
+
+void
+ms_objv8_write_macro_fmla (BiffPut *bp,
+			   ExcelWriteSheet *esheet,
+			   GnmExprTop const *texpr)
+{
+	char hfmla[10];
+	unsigned pos, end_pos;
+	guint16 fmla_len;
+
+	pos = bp->curpos;
+	GSF_LE_SET_GUINT16 (hfmla, GR_MACRO);
+	GSF_LE_SET_GUINT16 (hfmla + 2, 0);  /* record len */
+	GSF_LE_SET_GUINT16 (hfmla + 4, 0);  /* formula len */
+	GSF_LE_SET_GUINT32 (hfmla + 6, 0);  /* calcid? */
+	ms_biff_put_var_write (bp, hfmla, sizeof hfmla);
+	fmla_len = excel_write_formula (esheet->ewb,
+					texpr,
+					esheet->gnum_sheet, 0, 0,
+					/* eh?  */
+					EXCEL_CALLED_FROM_VALIDATION);
+	end_pos = bp->curpos;
+	ms_biff_put_var_seekto (bp, pos);
+	GSF_LE_SET_GUINT16 (hfmla + 2, fmla_len + 6);
+	GSF_LE_SET_GUINT16 (hfmla + 4, fmla_len);
+	ms_biff_put_var_write (bp, hfmla, sizeof hfmla);
+	ms_biff_put_var_seekto (bp, end_pos);
+}
+
+void
+ms_objv8_write_radiobutton (BiffPut *bp)
+{
+	char rb[10];
+
+	GSF_LE_SET_GUINT16 (rb, GR_RADIO_BUTTON);
+	GSF_LE_SET_GUINT16 (rb + 2, sizeof (rb) - 4);
+	GSF_LE_SET_GUINT32 (rb + 4, 0);  /* ignore */
+	GSF_LE_SET_GUINT16 (rb + 8, 0);  /* ignore */
+	ms_biff_put_var_write (bp, rb, sizeof rb);
+}
