@@ -13,6 +13,7 @@
  **/
 
 #include "ms-excel-read.h"
+#include "ms-excel-write.h"
 
 #define MS_ANCHOR_SIZE	18
 
@@ -71,6 +72,7 @@ typedef enum {
 	MS_OBJ_ATTR_IS_EXPR_MASK = 0x20000,
 	MS_OBJ_ATTR_LINKED_TO_CELL,
 	MS_OBJ_ATTR_INPUT_FROM,
+	MS_OBJ_ATTR_MACRO_EXPR,
 
     /* GObjects */
 	MS_OBJ_ATTR_IS_GOBJECT_MASK = 0x40000,
@@ -151,4 +153,14 @@ void ms_objv8_write_scrollbar	(BiffPut *bp);
 void ms_objv8_write_listbox	(BiffPut *bp, gboolean filtered);
 void ms_objv8_write_note	(BiffPut *bp);
 
+void ms_objv8_write_checkbox_data (BiffPut *bp, gboolean active);
+void ms_objv8_write_checkbox_link (BiffPut *bp);
+void ms_objv8_write_checkbox_fmla (BiffPut *bp,
+				   ExcelWriteSheet *esheet,
+				   GnmExprTop const *texpr);
+void ms_objv8_write_macro_fmla    (BiffPut *bp,
+				   ExcelWriteSheet *esheet,
+				   GnmExprTop const *texpr);
+void ms_objv8_write_radiobutton (BiffPut *bp);
+
 #endif /* GNM_MS_OBJ_H */
