@@ -1,3 +1,4 @@
+/* vim: set sw=8: -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
 /*
  * html.c
  *
@@ -120,18 +121,18 @@ html_get_text_color (GnmCell *cell, GnmStyle const *style, guint *r, guint *g, g
 	if (fore == 0)
 		*r = *g = *b = 0;
 	else {
-		*r = UINT_RGBA_R (fore);
-		*g = UINT_RGBA_G (fore);
-		*b = UINT_RGBA_B (fore);
+		*r = GO_COLOR_UINT_R (fore);
+		*g = GO_COLOR_UINT_G (fore);
+		*b = GO_COLOR_UINT_B (fore);
 	}
 }
 static void
 html_get_back_color (GnmStyle const *style, guint *r, guint *g, guint *b)
 {
 	GnmColor const *color = gnm_style_get_back_color (style);
-	*r = color->gdk_color.red >> 8;
-	*g = color->gdk_color.green >> 8;
-	*b = color->gdk_color.blue >> 8;
+	*r = GO_COLOR_UINT_R (color->go_color);
+	*g = GO_COLOR_UINT_G (color->go_color);
+	*b = GO_COLOR_UINT_B (color->go_color);
 }
 
 /*****************************************************************************/
@@ -161,14 +162,21 @@ cb_html_attrs_as_string (GsfOutput *output, PangoAttribute *a, html_version_t ve
 	case PANGO_ATTR_SIZE :
 		break; /* ignored */
 	case PANGO_ATTR_RISE:
-		break; /* ignored */
+		if (((PangoAttrInt *)a)->value > 5) {
+			gsf_output_puts (output, "<sup>");
+			closure = "</sup>";
+		} else if (((PangoAttrInt *)a)->value < -5) {
+			gsf_output_puts (output, "<sub>");
+			closure = "</sub>";
+		}
+		break;
 	case PANGO_ATTR_STYLE :
 		if (((PangoAttrInt *)a)->value == PANGO_STYLE_ITALIC) {
 			gsf_output_puts (output, "<i>");
 			closure = "</i>";
 		}
 		break;
-	case PANGO_ATTR_WEIGHT : 
+	case PANGO_ATTR_WEIGHT :
 		if (((PangoAttrInt *)a)->value > 600){
 			gsf_output_puts (output, "<b>");
 			closure = "</b>";
@@ -180,8 +188,8 @@ cb_html_attrs_as_string (GsfOutput *output, PangoAttribute *a, html_version_t ve
 			closure = "</strike>";
 		}
 		break;
-	case PANGO_ATTR_UNDERLINE : 
-		if ((version != HTML40) && 
+	case PANGO_ATTR_UNDERLINE :
+		if ((version != HTML40) &&
 		    (((PangoAttrInt *)a)->value != PANGO_UNDERLINE_NONE)) {
 			gsf_output_puts (output, "<u>");
 			closure = "</u>";
@@ -202,7 +210,7 @@ cb_html_attrs_as_string (GsfOutput *output, PangoAttribute *a, html_version_t ve
 }
 
 static void
-html_new_markup (GsfOutput *output, const PangoAttrList *markup, char const *text, 
+html_new_markup (GsfOutput *output, const PangoAttrList *markup, char const *text,
 		 html_version_t version)
 {
 	int handled = 0;
@@ -215,7 +223,7 @@ html_new_markup (GsfOutput *output, const PangoAttrList *markup, char const *tex
 
 	do {
 		GSList *list, *l;
-		
+
 		g_string_erase (closure, 0, -1);
 		pango_attr_iterator_range (iter, &from, &to);
 		from = (from > len) ? len : from; /* Since "from" can be really big! */
@@ -271,6 +279,16 @@ html_write_cell_content (GsfOutput *output, GnmCell *cell, GnmStyle const *style
 				gsf_output_puts (output, "<u>");
 			if (font_is_monospaced (style))
 				gsf_output_puts (output, "<tt>");
+			switch (gnm_style_get_font_strike (style)) {
+			case GO_FONT_SCRIPT_SUB:
+				gsf_output_puts (output, "<sub>");
+				break;
+			case GO_FONT_SCRIPT_SUPER:
+				gsf_output_puts (output, "<sup>");
+				break;
+			default:
+				break;
+			}
 		}
 
 		if (hlink_target)
@@ -285,11 +303,11 @@ html_write_cell_content (GsfOutput *output, GnmCell *cell, GnmStyle const *style
 					gsf_output_printf (output, "<font color=\"#%02X%02X%02X\">", r, g, b);
 			}
 
-			if ((cell->value->type == VALUE_STRING) 
+			if ((cell->value->type == VALUE_STRING)
 			    && (VALUE_FMT (cell->value) != NULL)
 			    && go_format_is_markup (VALUE_FMT (cell->value)))
 				markup = go_format_get_markup (VALUE_FMT (cell->value));
-			
+
 			if (markup != NULL) {
 				GString *str = g_string_new ("");
 				value_get_as_gstring (cell->value, str, NULL);
@@ -307,6 +325,16 @@ html_write_cell_content (GsfOutput *output, GnmCell *cell, GnmStyle const *style
 		if (hlink_target)
 			gsf_output_puts (output, "</a>");
 		if (style != NULL) {
+			switch (gnm_style_get_font_strike (style)) {
+			case GO_FONT_SCRIPT_SUB:
+				gsf_output_puts (output, "</sub>");
+				break;
+			case GO_FONT_SCRIPT_SUPER:
+				gsf_output_puts (output, "</sup>");
+				break;
+			default:
+				break;
+			}
 			if (font_is_monospaced (style))
 				gsf_output_puts (output, "</tt>");
 			if (gnm_style_get_font_uline (style) != UNDERLINE_NONE)
@@ -371,9 +399,9 @@ html_get_border_style (GnmBorder *border)
 
 	if (border->color) {
 		guint r, g, b;
-		r = border->color->gdk_color.red >> 8;
-		g = border->color->gdk_color.green >> 8;
-		b = border->color->gdk_color.blue >> 8;
+		r = GO_COLOR_UINT_R (border->color->go_color);
+		g = GO_COLOR_UINT_G (border->color->go_color);
+		b = GO_COLOR_UINT_B (border->color->go_color);
 		g_string_append_printf (text, " #%02X%02X%02X", r, g, b);
 	}
 
