@@ -1153,6 +1153,7 @@ gnm_pane_new (SheetControlGUI *scg,
 	pane->index      = index;
 	pane->simple.scg = scg;
 
+	goc_canvas_set_document (GOC_CANVAS (pane), wb_control_get_doc (scg_wbc (scg)));
 	if (NULL != (sheet = scg_sheet (scg)) &&
 	    fabs (1. - sheet->last_zoom_factor_used) > 1e-6)
 		goc_canvas_set_pixels_per_unit (GOC_CANVAS (pane),
@@ -2895,7 +2896,7 @@ set_acetate_coords (GnmPane *pane, SheetObject *so, GocItem **ctrl_pts,
 
 		style->fill.auto_type = FALSE;
 		style->fill.type  = GO_STYLE_FILL_PATTERN;
-		style->fill.auto_fore = FALSE;
+		style->fill.auto_back = FALSE;
 		go_pattern_set_solid (&style->fill.pattern, 0);
 		style->line.auto_dash = FALSE;
 		style->line.dash_type = GO_LINE_NONE;
