@@ -14,34 +14,26 @@
 #include "gnumeric.h"
 #include "gui-util.h"
 #include "io-context-gtk.h"
-#include <goffice/app/io-context-priv.h>
+#include <goffice/goffice.h>
 #include "application.h"
 #include "libgnumeric.h"
 #include "dialogs.h"
 #include "pixmaps/gnumeric-stock-pixbufs.h"
 
 #include <gsf/gsf-impl-utils.h>
-#include <gtk/gtkdialog.h>
-#include <gtk/gtklabel.h>
-#include <gtk/gtkmessagedialog.h>
-#include <gtk/gtkprogressbar.h>
-#include <gtk/gtkvbox.h>
-#include <gtk/gtkwindow.h>
-#include <gtk/gtkimage.h>
-#include <gtk/gtkframe.h>
-#include <gtk/gtkicontheme.h>
+#include <gtk/gtk.h>
 #include <stdlib.h>
 #include <string.h>
 
 #define ICG_POPUP_DELAY 3.0
 
 #define IO_CONTEXT_GTK_CLASS(klass) \
-    (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_IO_CONTEXT_GTK, IOContextGtk))
-#define IS_IO_CONTEXT_GTK_CLASS(klass) \
-    (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_IO_CONTEXT_GTK))
+    (G_TYPE_CHECK_CLASS_CAST ((klass), GO_TYPE_IO_CONTEXT_GTK, IOContextGtk))
+#define GO_IS_IO_CONTEXT_GTK_CLASS(klass) \
+    (G_TYPE_CHECK_CLASS_TYPE ((klass), GO_TYPE_IO_CONTEXT_GTK))
 
-struct _IOContextGtk {
-	IOContext parent;
+struct _GOIOContextGtk {
+	GOIOContext parent;
 	GtkWindow *window;
 	GtkWindow *parent_window;
 	GtkProgressBar *file_bar;
@@ -60,8 +52,8 @@ struct _IOContextGtk {
 	gboolean show_warnings;
 };
 
-struct _IOContextGtkClass {
-	IOContextClass parent_class;
+struct _GOIOContextGtkClass {
+	GOIOContextClass parent_class;
 };
 
 enum {
@@ -266,11 +258,11 @@ icg_progress_message_set (GOCmdContext *cc, gchar const *msg)
 }
 
 static void
-icg_error_error_info (GOCmdContext *cc, ErrorInfo *error)
+icg_error_error_info (GOCmdContext *cc, GOErrorInfo *error)
 {
 	IOContextGtk *icg = IO_CONTEXT_GTK (cc);
 	if (icg->show_warnings) {
-		GtkWidget *dialog = gnumeric_error_info_dialog_new (error);
+		GtkWidget *dialog = gnumeric_go_error_info_dialog_new (error);
 		gtk_widget_show_all (GTK_WIDGET (dialog));
 		gtk_dialog_run (GTK_DIALOG (dialog));
 		gtk_widget_destroy (dialog);
@@ -278,13 +270,13 @@ icg_error_error_info (GOCmdContext *cc, ErrorInfo *error)
 }
 
 static void
-icg_set_num_files (IOContext *icg, guint files_total)
+icg_set_num_files (GOIOContext *icg, guint files_total)
 {
 	IO_CONTEXT_GTK (icg)->files_total = files_total;
 }
 
 static void
-icg_processing_file (IOContext *ioc, char const *file)
+icg_processing_file (GOIOContext *ioc, char const *file)
 {
 	IOContextGtk *icg = IO_CONTEXT_GTK (ioc);
 
@@ -347,7 +339,7 @@ icg_finalize (GObject *obj)
 		g_timer_destroy (icg->timer);
 	icg->timer = NULL;
 
-	G_OBJECT_CLASS (g_type_class_peek (TYPE_IO_CONTEXT))->finalize (obj);
+	G_OBJECT_CLASS (g_type_class_peek (GO_TYPE_IO_CONTEXT))->finalize (obj);
 }
 
 static void
@@ -380,7 +372,7 @@ icg_gnm_cmd_context_init (GOCmdContextClass *cc_class)
 static void
 icg_class_init (GObjectClass *gobj_klass)
 {
-	IOContextClass *ioc_klass = (IOContextClass *)gobj_klass;
+	GOIOContextClass *ioc_klass = (GOIOContextClass *)gobj_klass;
 
 	gobj_klass->finalize	   = icg_finalize;
 	gobj_klass->set_property   = icg_set_property;
@@ -421,8 +413,8 @@ icg_init (IOContextGtk *icg)
 
 GSF_CLASS_FULL (IOContextGtk, io_context_gtk,
 		NULL, NULL, icg_class_init, NULL,
-		icg_init, TYPE_IO_CONTEXT, 0,
-		GSF_INTERFACE (icg_gnm_cmd_context_init, GO_CMD_CONTEXT_TYPE))
+		icg_init, GO_TYPE_IO_CONTEXT, 0,
+		GSF_INTERFACE (icg_gnm_cmd_context_init, GO_TYPE_CMD_CONTEXT))
 
 void
 icg_set_transient_for (IOContextGtk *icg, GtkWindow *parent_window)
