@@ -4,7 +4,8 @@
 
 #include <gnumeric.h>
 #include <position.h>
-#include <goffice/utils/regutf8.h>
+#include <numbers.h>
+#include <goffice/goffice.h>
 
 G_BEGIN_DECLS
 
@@ -43,7 +44,7 @@ typedef enum {
 typedef  int (*GnmSearchReplaceQueryFunc) (GnmSearchReplaceQuery q, GnmSearchReplace *sr, ...);
 
 struct _GnmSearchReplace {
-	GoSearchReplace base;
+	GOSearchReplace base;
 
 	GnmSearchReplaceScope scope;
 	char *range_text;
@@ -56,6 +57,9 @@ struct _GnmSearchReplace {
 
 	gboolean query;		/* Ask before each change.  */
 
+	gboolean is_number;     /* Search for specific number.  */
+	gnm_float low_number, high_number;   /* protected. */
+
 	/* The following identify what kinds of cells are the target.  */
 	gboolean search_strings;
 	gboolean search_other_values;
