@@ -17,26 +17,30 @@
 #include "dependent.h"
 #include "sheet-view.h"
 #include "sheet-control.h"
+#include "sheet-control-gui.h"
 #include "sheet-private.h"
 #include "dialogs.h"
 #include "sheet-object-impl.h"
 #include "expr.h"
 #include "ranges.h"
 #include "commands.h"
+#include "gui-util.h"
 
+#include "gnm-pane-impl.h"
 #include "gnm-so-line.h"
 #include "gnm-so-filled.h"
+#include "sheet-control-gui-priv.h"
 #include "sheet-object-cell-comment.h"
 #include "sheet-object-widget.h"
 #include "sheet-object-graph.h"
 #include "sheet-object-image.h"
+#include "wbc-gtk-impl.h"
 #include "graph.h"
 #include <goffice/goffice.h>
 #include "application.h"
 #include "gutils.h"
 
 #include <libxml/globals.h>
-#include <goffice/cut-n-paste/foocanvas/foo-canvas.h>
 #include <gsf/gsf-impl-utils.h>
 
 #include <string.h>
@@ -44,6 +48,11 @@
 /* Returns the class for a SheetObject */
 #define SO_CLASS(so) SHEET_OBJECT_CLASS(G_OBJECT_GET_CLASS(so))
 
+enum {
+	SO_PROP_0 = 0,
+	SO_PROP_NAME
+};
+
 enum {
 	BOUNDS_CHANGED,
 	UNREALIZED,
@@ -183,12 +192,58 @@ sheet_objects_max_extent (Sheet *sheet)
 	}
 }
 
+void
+sheet_object_set_name (SheetObject *so, const char *name)
+{
+	if (name == so->name)
+		return;
+
+	g_free (so->name);
+	so->name = g_strdup (name);
+
+	g_object_notify (G_OBJECT (so), "name");
+}
+
+static void
+sheet_object_get_property (GObject *obj, guint param_id,
+			   GValue  *value, GParamSpec *pspec)
+{
+	SheetObject *so = SHEET_OBJECT (obj);
+
+	switch (param_id) {
+	case SO_PROP_NAME:
+		g_value_set_string (value, so->name);
+		break;
+	default :
+		G_OBJECT_WARN_INVALID_PROPERTY_ID (obj, param_id, pspec);
+		break;
+	}
+}
+
+static void
+sheet_object_set_property (GObject *obj, guint param_id,
+			   GValue const *value, GParamSpec *pspec)
+{
+	SheetObject *so = SHEET_OBJECT (obj);
+
+	switch (param_id) {
+	case SO_PROP_NAME:
+		sheet_object_set_name (so, g_value_get_string (value));
+		break;
+	default:
+		G_OBJECT_WARN_INVALID_PROPERTY_ID (obj, param_id, pspec);
+		return;
+	}
+}
+
+
 static void
 sheet_object_finalize (GObject *object)
 {
 	SheetObject *so = SHEET_OBJECT (object);
 	if (so->sheet != NULL)
 		sheet_object_clear_sheet (so);
+	g_free (so->name);
 	parent_klass->finalize (object);
 }
 
@@ -225,7 +280,11 @@ sheet_object_class_init (GObjectClass *klass)
 	SheetObjectClass *sheet_object_class = SHEET_OBJECT_CLASS (klass);
 
 	parent_klass = g_type_class_peek_parent (klass);
+
 	klass->finalize = sheet_object_finalize;
+	klass->get_property = sheet_object_get_property;
+	klass->set_property = sheet_object_set_property;
+
 	sheet_object_class->populate_menu        = sheet_object_populate_menu_real;
 	sheet_object_class->user_config          = NULL;
 	sheet_object_class->rubber_band_directly = FALSE;
@@ -234,6 +293,11 @@ sheet_object_class_init (GObjectClass *klass)
 	sheet_object_class->xml_export_name	 = NULL;
 	sheet_object_class->foreach_dep          = NULL;
 
+	g_object_class_install_property
+		(klass, SO_PROP_NAME,
+		 g_param_spec_string ("name", NULL, NULL, NULL,
+				      GSF_PARAM_STATIC | G_PARAM_READWRITE));
+
 	signals [BOUNDS_CHANGED] = g_signal_new ("bounds-changed",
 		SHEET_OBJECT_TYPE,
 		G_SIGNAL_RUN_LAST,
@@ -333,7 +397,6 @@ cb_create_views (SheetObject *so)
 	g_object_set_data (G_OBJECT (so), "create_view_handler", NULL);
 	SHEET_FOREACH_CONTROL (so->sheet, view, control,
 		sc_object_create_view (control, so););
-	sheet_object_update_bounds (so, NULL);
 	return FALSE;
 }
 
@@ -404,9 +467,12 @@ sheet_object_clear_sheet (SheetObject *so)
 		g_object_set_data (G_OBJECT (so), "create_view_handler", NULL);
 	}
 
-	/* The views remove themselves from the list */
-	while (so->realized_list != NULL)
-		sheet_object_view_destroy (so->realized_list->data);
+	while (so->realized_list != NULL) {
+		g_object_set_qdata (G_OBJECT (so->realized_list->data), sov_so_quark, NULL);
+		g_object_unref (G_OBJECT (so->realized_list->data));
+		so->realized_list = g_list_remove (so->realized_list, so->realized_list->data);
+
+	}
 	g_signal_emit (so, signals [UNREALIZED], 0);
 
 	if (SO_CLASS (so)->remove_from_sheet &&
@@ -476,13 +542,6 @@ sheet_object_foreach_dep (SheetObject *so,
 		SO_CLASS (so)->foreach_dep (so, func, user);
 }
 
-
-static void
-cb_sheet_object_view_finalized (SheetObject *so, GObject *view)
-{
-	so->realized_list = g_list_remove (so->realized_list, view);
-}
-
 /**
  * sheet_object_new_view:
  * @so :
@@ -513,8 +572,6 @@ sheet_object_new_view (SheetObject *so, SheetObjectViewContainer *container)
 	/* Store some useful information */
 	g_object_set_qdata (G_OBJECT (view), sov_so_quark, so);
 	g_object_set_qdata (G_OBJECT (view), sov_container_quark, container);
-	g_object_weak_ref (G_OBJECT (view),
-		(GWeakNotify) cb_sheet_object_view_finalized, so);
 	so->realized_list = g_list_prepend (so->realized_list, view);
 	sheet_object_update_bounds (so, NULL);
 
@@ -1077,27 +1134,29 @@ sheet_object_adjust_stacking (SheetObject *so, gint offset)
 
 	/* TODO : Move this to the container */
 	for (l = so->realized_list; l; l = l->next) {
-		FooCanvasItem *item = FOO_CANVAS_ITEM (l->data);
+		GocItem *item = GOC_ITEM (l->data);
 		if (offset > 0)
-			foo_canvas_item_raise (item, offset);
+			goc_item_raise (item, offset);
 		else
-			foo_canvas_item_lower (item, - offset);
+			goc_item_lower (item, - offset);
 	}
 	return cur - i;
 }
 
 /*****************************************************************************/
 
+static GObjectClass *view_parent_class;
+
 void
 sheet_object_view_set_bounds (SheetObjectView *sov,
 			      double const *coords, gboolean visible)
 {
-	SheetObjectViewIface *iface;
+	SheetObjectViewClass *klass;
 
 	g_return_if_fail (IS_SHEET_OBJECT_VIEW (sov));
-	iface = SHEET_OBJECT_VIEW_GET_CLASS (sov);
-	if (NULL != iface->set_bounds)
-		(iface->set_bounds) (sov, coords, visible);
+	klass = SHEET_OBJECT_VIEW_GET_CLASS (sov);
+	if (NULL != klass->set_bounds)
+		(klass->set_bounds) (sov, coords, visible);
 }
 
 SheetObject *
@@ -1106,34 +1165,89 @@ sheet_object_view_get_so (SheetObjectView *view)
 	return g_object_get_qdata (G_OBJECT (view), sov_so_quark);
 }
 
-void
-sheet_object_view_destroy (SheetObjectView *sov)
+static gboolean
+sheet_object_view_enter_notify (GocItem *item, double x, double y)
 {
-	SheetObjectViewIface *iface = SHEET_OBJECT_VIEW_GET_CLASS (sov);
-	g_return_if_fail (iface != NULL);
-	if (iface->destroy)
-		iface->destroy (sov);
-}
+	SheetObject *so;
 
-GType
-sheet_object_view_get_type (void)
-{
-	static GType type = 0;
-
-	if (!type) {
-		static GTypeInfo const type_info = {
-			sizeof (SheetObjectViewIface),	/* class_size */
-			NULL,				/* base_init */
-			NULL,				/* base_finalize */
-		};
-
-		type = g_type_register_static (G_TYPE_INTERFACE,
-			"SheetObjectView", &type_info, 0);
+	if (scg_wbcg (GNM_SIMPLE_CANVAS (item->canvas)->scg)->new_object) {
+		ItemGrid *grid = GNM_PANE (item->canvas)->grid;
+		return GOC_ITEM_GET_CLASS (grid)->enter_notify (GOC_ITEM (grid), x, y);
 	}
 
-	return type;
+	so = (SheetObject *) g_object_get_qdata (G_OBJECT (item), sov_so_quark);
+	gnm_widget_set_cursor_type (GTK_WIDGET (item->canvas),
+		(so->flags & SHEET_OBJECT_CAN_PRESS) ? GDK_HAND2 : GDK_ARROW);
+	return FALSE;
 }
 
+static gboolean
+sheet_object_view_button_pressed (GocItem *item, int button, double x, double y)
+{
+	GnmPane *pane;
+	SheetObject *so;
+
+	if (scg_wbcg (GNM_SIMPLE_CANVAS (item->canvas)->scg)->new_object) {
+		ItemGrid *grid = GNM_PANE (item->canvas)->grid;
+		return GOC_ITEM_GET_CLASS (grid)->button_pressed (GOC_ITEM (grid), button, x, y);
+	}
+
+	if (button > 3)
+		return FALSE;
+
+	pane = GNM_PANE (item->canvas);
+	so = (SheetObject *) g_object_get_qdata (G_OBJECT (item), sov_so_quark);
+
+	x *= goc_canvas_get_pixels_per_unit (item->canvas);
+	y *= goc_canvas_get_pixels_per_unit (item->canvas);
+	/* cb_sheet_object_widget_canvas_event calls even if selected */
+	if (NULL == g_hash_table_lookup (pane->drag.ctrl_pts, so)) {
+		SheetObjectClass *soc =
+			G_TYPE_INSTANCE_GET_CLASS (so, SHEET_OBJECT_TYPE, SheetObjectClass);
+		GdkEventButton *event = (GdkEventButton *) goc_canvas_get_cur_event (item->canvas);
+
+		if (soc->interactive && button != 3)
+			return FALSE;
+
+		if (!(event->state & GDK_SHIFT_MASK))
+			scg_object_unselect (pane->simple.scg, NULL);
+		scg_object_select (pane->simple.scg, so);
+		if (NULL == g_hash_table_lookup (pane->drag.ctrl_pts, so))
+			return FALSE;	/* protected ? */
+	}
+
+	if (button < 3)
+		gnm_pane_object_start_resize (pane, button, x, y, so, 8, FALSE);
+	else
+		gnm_pane_display_object_menu (pane, so, goc_canvas_get_cur_event (item->canvas));
+	return TRUE;
+}
+
+static void
+sheet_object_view_finalize (GObject *obj)
+{
+	SheetObject *so = (SheetObject *) g_object_get_qdata (obj, sov_so_quark);
+	if (so)
+		so->realized_list = g_list_remove (so->realized_list, obj);
+	view_parent_class->finalize (obj);
+}
+
+static void
+sheet_object_view_class_init (GocItemClass *item_klass)
+{
+	GObjectClass *obj_klass = (GObjectClass *) item_klass;
+	view_parent_class = g_type_class_peek_parent (item_klass);
+
+	obj_klass->finalize = sheet_object_view_finalize;
+
+	item_klass->enter_notify = sheet_object_view_enter_notify;
+	item_klass->button_pressed = sheet_object_view_button_pressed;
+}
+
+GSF_CLASS (SheetObjectView, sheet_object_view,
+	   sheet_object_view_class_init, NULL,
+	   GOC_TYPE_GROUP)
+
 /*****************************************************************************/
 
 GType
