@@ -237,7 +237,7 @@ list_them (get_them_f get_them,
  */
 static GSList *
 read_files_to_merge (const char *inputs[], GOFileOpener *fo,
-		     IOContext *io_context, GOCmdContext *cc)
+		     GOIOContext *io_context, GOCmdContext *cc)
 {
 	GSList *wbs = NULL;
 
@@ -250,7 +250,7 @@ read_files_to_merge (const char *inputs[], GOFileOpener *fo,
 		g_free (uri);
 		inputs++;
 
-		if (gnumeric_io_error_occurred (io_context)) {
+		if (go_io_error_occurred (io_context)) {
 			go_slist_free_custom (wbs, g_object_unref);
 			return NULL;
 		}
@@ -381,15 +381,15 @@ merge_single (Workbook *wb, Workbook *wb2,
 /* Merge a collection of workbooks into one. */
 static gboolean
 merge (Workbook *wb, char const *inputs[],
-       GOFileOpener *fo, IOContext *io_context, GOCmdContext *cc)
+       GOFileOpener *fo, GOIOContext *io_context, GOCmdContext *cc)
 {
 	GSList *wbs, *l;
 	int result = 0;
 	int cmax, rmax;
 
 	wbs = read_files_to_merge (inputs, fo, io_context, cc);
-	if (gnumeric_io_error_occurred (io_context)) {
-		gnumeric_io_error_display (io_context);
+	if (go_io_error_occurred (io_context)) {
+		go_io_error_display (io_context);
 		return TRUE;
 	}
 
@@ -472,7 +472,7 @@ convert (char const *inarg, char const *outarg, char const *mergeargs[],
 	}
 
 	if (fs != NULL) {
-		IOContext *io_context = gnumeric_io_context_new (cc);
+		GOIOContext *io_context = go_io_context_new (cc);
 		WorkbookView *wbv;
 		if (mergeargs==NULL) {
 			wbv = wb_view_new_from_uri (infile, fo,
@@ -482,8 +482,8 @@ convert (char const *inarg, char const *outarg, char const *mergeargs[],
 			wbv = workbook_view_new (NULL);
 		}
 
-		if (wbv == NULL || gnumeric_io_error_occurred (io_context)) {
-			gnumeric_io_error_display (io_context);
+		if (wbv == NULL || go_io_error_occurred (io_context)) {
+			go_io_error_display (io_context);
 			res = 1;
 		} else {
 			Workbook *wb = wb_view_get_workbook (wbv);
@@ -523,7 +523,7 @@ convert (char const *inarg, char const *outarg, char const *mergeargs[],
 					     wb,
 					     ssconvert_range);
 			else if (workbook_sheet_count (wb) > 1 &&
-				 go_file_saver_get_save_scope (fs) != FILE_SAVE_WORKBOOK) {
+				 go_file_saver_get_save_scope (fs) != GO_FILE_SAVE_WORKBOOK) {
 				if (ssconvert_one_file_per_sheet) {
 					g_warning ("TODO: one sheet per file is not implemented");
 				} else
@@ -548,7 +548,7 @@ convert (char const *inarg, char const *outarg, char const *mergeargs[],
 int
 main (int argc, char const **argv)
 {
-	ErrorInfo	*plugin_errs;
+	GOErrorInfo	*plugin_errs;
 	int		 res = 0;
 	GOCmdContext	*cc;
 	GOptionContext *ocontext;
@@ -576,7 +576,7 @@ main (int argc, char const **argv)
 		return 0;
 	}
 
-	gnm_init (FALSE);
+	gnm_init ();
 
 	cc = cmd_context_stderr_new ();
 	gnm_plugins_init (GO_CMD_CONTEXT (cc));
@@ -584,7 +584,7 @@ main (int argc, char const **argv)
 		go_plugins_get_available_plugins (), &plugin_errs);
 	if (plugin_errs) {
 		/* FIXME: What do we want to do here? */
-		error_info_free (plugin_errs);
+		go_error_info_free (plugin_errs);
 	}
 
 	if (ssconvert_list_exporters)
