@@ -25,6 +25,7 @@
 
 #include <gnumeric-config.h>
 #include <gnumeric.h>
+#include <glib/gi18n-lib.h>
 #include <xml-sax.h>
 #include <workbook-view.h>
 #include <gnm-format.h>
@@ -50,7 +51,6 @@
 #include <sheet-filter.h>
 #include <sheet-object-impl.h>
 #include <print-info.h>
-#include <xml-io.h>
 #include <gutils.h>
 #include <clipboard.h>
 #include <tools/scenarios.h>
@@ -79,6 +79,27 @@ typedef struct {
 /* Precision to use when saving point measures. */
 #define POINT_SIZE_PRECISION 4
 
+void
+gnm_xml_out_add_gocolor (GsfXMLOut *o, char const *id, GOColor c)
+{
+	GdkColor tmp;
+	go_color_to_gdk (c, &tmp);
+	gsf_xml_out_add_color (o, id, tmp.red, tmp.green, tmp.blue);
+}
+
+static void
+gnm_xml_out_add_color (GsfXMLOut *o, char const *id, GnmColor const *c)
+{
+	gnm_xml_out_add_gocolor (o, id, c->go_color);
+}
+
+static void
+gnm_xml_out_add_cellpos (GsfXMLOut *o, char const *id, GnmCellPos const *p)
+{
+	g_return_if_fail (p != NULL);
+	gsf_xml_out_add_cstr_unchecked (o, id, cellpos_as_string (p));
+}
+
 static void
 xml_out_add_range (GsfXMLOut *xml, GnmRange const *r)
 {
@@ -1089,6 +1110,8 @@ xml_write_objects (GnmOutputXML *state, GSList *objects)
 
 		tmp = g_strconcat (GNM, type_name, NULL);
 		gsf_xml_out_start_element (state->output, tmp);
+		if (so->name)
+			gsf_xml_out_add_cstr (state->output, "Name", so->name);
 		gsf_xml_out_add_cstr (state->output, "ObjectBound", range_as_string (&so->anchor.cell_bound));
 		snprintf (buffer, sizeof (buffer), "%.3g %.3g %.3g %.3g",
 			  so->anchor.offset [0], so->anchor.offset [1],
@@ -1266,7 +1289,7 @@ gnm_xml_io_conventions (void)
 	return res;
 }
 
-void
+static void
 gnm_xml_file_save (GOFileSaver const *fs, GOIOContext *io_context,
 		   gconstpointer wb_view, GsfOutput *output)
 {
@@ -1432,6 +1455,7 @@ gnm_cellregion_to_xml (GnmCellRegion const *cr)
 				range_as_string (ptr->data));
 			gsf_xml_out_end_element (state.state.output); /* </Merge> */
 		}
+		gsf_xml_out_end_element (state.state.output); /* </gnm:MergedRegions> */
 	}
 
 	/* NOTE SNEAKY : ensure that sheet names have explicit workbooks */
@@ -1462,3 +1486,19 @@ gnm_cellregion_to_xml (GnmCellRegion const *cr)
 
 	return GSF_OUTPUT_MEMORY (buf);
 }
+
+
+void
+gnm_xml_sax_write_init (void)
+{
+	GOFileSaver *saver = go_file_saver_new
+		("Gnumeric_XmlIO:sax",
+		 "gnumeric",
+		 _("Gnumeric XML (*.gnumeric)"),
+		 GO_FILE_FL_AUTO, gnm_xml_file_save);
+	g_object_set (G_OBJECT (saver),
+		      "mime-type", "application/x-gnumeric",
+		      NULL);
+
+	go_file_saver_register_as_default (saver, 50);
+}
